@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Generate walking basslines
 
-our $VERSION = '0.0100';
+our $VERSION = '0.0101';
 
 use Data::Dumper::Compact qw(ddc);
 use Carp qw(croak);
@@ -39,10 +39,10 @@ has verbose => (
 
 
 sub generate {
-    my ($self, $chord, $duration) = @_;
+    my ($self, $chord, $num) = @_;
 
     $chord ||= 'C';
-    $duration ||= 4;
+    $num ||= 4;
 
     my $scale = $chord =~ /^[A-G][#b]?m/ ? 'minor' : 'major';
 
@@ -103,10 +103,7 @@ sub generate {
     $voice->context($fixed[int @fixed / 2]);
 
     # Choose Or Die!!
-    my @chosen;
-    for (1 .. $duration) {
-        push @chosen, $voice->rand;
-    }
+    my @chosen = map { $voice->rand } 1 .. $num;;
 
     # Show them what they've won, Bob!
     @named = map { Music::Note->new($_, 'midinum')->format('ISO') } @chosen;
@@ -129,7 +126,7 @@ MIDI::Bassline::Walk - Generate walking basslines
 
 =head1 VERSION
 
-version 0.0100
+version 0.0101
 
 =head1 SYNOPSIS
 
@@ -187,15 +184,14 @@ Create a new C<MIDI::Bassline::Walk> object.
 =head2 generate
 
   $notes = $bassline->generate;
-  $notes = $bassline->generate($chord, $duration);
+  $notes = $bassline->generate($chord, $n);
 
-Generate a walking bassline over the given B<chord> for B<duration>
-quarter notes.
+Generate B<n> MIDI pitch numbers given the given B<chord>.
 
 Defaults:
 
   chord: C
-  duration: 4
+  n: 4
 
 =head1 SEE ALSO
 
